POWER = 0xe000
""" Toggle power of device. """

OK = 0xe001
""" Confirm, exact meaning depends on context. """

BACK = 0xe002
""" Go back, exact meaning depends on context. """

CHAN_UP = 0xe006
""" Select next channel. """

CHAN_DOWN = 0xe007
""" Select previous channel. """

HELP = 0xe009
""" The F1 key for your set-top box. """

MENU = 0xe00a
MENU1 = 0xe011
MENU2 = 0xe015
""" Toggle the main menu. """

GUIDE = 0xe00b
""" Show TV guide. """

INFO = 0xe00e
""" Toggle info for TV show of current channel. """

TEXT = 0xe00f
""" Toggle teletext. """

DPAD_UP = 0xe100
""" Navigate up. """

DPAD_DOWN = 0xe101
""" Navigate down. """

DPAD_LEFT = 0xe102
""" Navigate left. """

DPAD_RIGHT = 0xe103
""" Navigate right. """

NUM_0 = 0xe300
NUM_1 = 0xe301
NUM_2 = 0xe302
NUM_3 = 0xe303
NUM_4 = 0xe304
NUM_5 = 0xe305
NUM_6 = 0xe306
NUM_7 = 0xe307
NUM_8 = 0xe308
NUM_9 = 0xe309

PAUSE = 0xe400
""" Pause media. """

STOP = 0xe402
""" Stop pausing. """

RECORD = 0xe403
""" Record media. """

FWD = 0xe405
""" Fast fowards. """

RWD = 0xe407
""" Fast backwards. """

TIMESHIFT_INFO = 0xef06
""" Meaning unknown. """

POWER2 = 0xef15
""" Meaning unknown. """

ID = 0xef16
""" Show Radio Frequency menu. """

RC_PAIR = 0xef17
""" Meaning unknown. """

TIMINGS = 0xef19
""" Meaning unknown. """

ONDEMAND = 0xef28
""" Open ondemand menu. """

DVR = 0xef29
""" Open DVR menu. """

TV = 0xef2a
""" Close all menus and go back to TV show or go to previous channel. """
